diff --git a/bilby/core/sampler/__init__.py b/bilby/core/sampler/__init__.py
index 0b81c26b37c2aac87ea8a53a4964657e1ad2ceec..1334ac0ace9f2cd925263903e78526b679b17e23 100644
--- a/bilby/core/sampler/__init__.py
+++ b/bilby/core/sampler/__init__.py
@@ -93,7 +93,7 @@ def run_sampler(likelihood, priors=None, label='label', outdir='outdir',
         saving. For example, if `meta_data={dtype: 'signal'}`. Warning: in case
         of conflict with keys saved by bilby, the meta_data keys will be
         overwritten.
-    save: bool
+    save: bool, str
         If true, save the priors and results to disk.
         If hdf5, save as an hdf5 file instead of json.
         If pickle or pkl, save as an pickle file instead of json.
diff --git a/bilby/core/result.py b/bilby/core/result.py
index 789fa5d9e9d386063b1be6d3e224dcad07dd04ea..7e25a9fda5f19e122b4418fd415ea5e38cf1e32c 100644
--- a/bilby/core/result.py
+++ b/bilby/core/result.py
@@ -42,7 +42,7 @@ def result_file_name(outdir, label, extension='json', gzip=False):
     label: str
         Naming scheme of the output file
     extension: str, optional
         Whether to save as `hdf5` or `json`
     gzip: bool, optional
         Set to True to append `.gz` to the extension for saving in gzipped format
 
@@ -730,11 +730,11 @@ class Result(object):
             default=False
         outdir: str, optional
             Path to the outdir. Default is the one stored in the result object.
-        extension: str, optional {json, hdf5, True}
+        extension: str, optional {json, hdf5, pickle, True}
             Determines the method to use to store the data (if True defaults
             to json)
         gzip: bool, optional
-            If true, and outputing to a json file, this will gzip the resulting
+            If true, and outputting to a json file, this will gzip the resulting
             file and add '.gz' to the file extension.
         """
 
@@ -42,7 +42,7 @@ def result_file_name(outdir, label, extension='json', gzip=False):
         Naming scheme of the output file
     extension: str, optional
-        Whether to save as `hdf5` or `json`
+        Whether to save as `hdf5`, `json`, or `pickle`
     gzip: bool, optional
         Set to True to append `.gz` to the extension for saving in gzipped format